@@ -1,31 +1,35 @@
 /*
  * ark -- archiver for the KDE project
  *
- * Copyright (C) 2008 Harald Hvaal <haraldhv (at@at) stud.ntnu.no>
+ * Copyright (C) 2008 Harald Hvaal <haraldhv@stud.ntnu.no>
  * Copyright (C) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "addtoarchive.h"
 #include "adddialog.h"
-
-#include <QFileInfo>
-#include <QDir>
-#include <QPointer>
+#include "archive.h"
+#include "jobs.h"
 
 #include <KConfig>
 #include <kdebug.h>
@@ -34,6 +38,11 @@
 #include <klocale.h>
 #include <KStandardDirs>
 
+#include <QFileInfo>
+#include <QDir>
+#include <QPointer>
+#include <QTimer>
+
 namespace Kerfuffle
 {
 AddToArchive::AddToArchive(QObject *parent)
@@ -45,6 +54,26 @@ AddToArchive::~AddToArchive()
 {
 }
 
+void AddToArchive::setAutoFilenameSuffix(const QString& suffix)
+{
+    m_autoFilenameSuffix = suffix;
+}
+
+void AddToArchive::setChangeToFirstPath(bool value)
+{
+    m_changeToFirstPath = value;
+}
+
+void AddToArchive::setFilename(const KUrl& path)
+{
+    m_filename = path.pathOrUrl();
+}
+
+void AddToArchive::setMimeType(const QString & mimeType)
+{
+    m_mimeType = mimeType;
+}
+
 bool AddToArchive::showAddDialog(void)
 {
     QPointer<Kerfuffle::AddDialog> dialog = new Kerfuffle::AddDialog(
@@ -57,8 +86,8 @@ bool AddToArchive::showAddDialog(void)
     bool ret = dialog->exec();
 
     if (ret) {
-        kDebug(1601) << "Returned URL:" << dialog->selectedUrl();
-        kDebug(1601) << "Returned mime:" << dialog->currentMimeFilter();
+        kDebug() << "Returned URL:" << dialog->selectedUrl();
+        kDebug() << "Returned mime:" << dialog->currentMimeFilter();
         setFilename(dialog->selectedUrl());
         setMimeType(dialog->currentMimeFilter());
     }
@@ -84,11 +113,16 @@ bool AddToArchive::addInput(const KUrl& url)
     return true;
 }
 
+void AddToArchive::start()
+{
+    QTimer::singleShot(0, this, SLOT(slotStartJob()));
+}
+
 // TODO: If this class should ever be called outside main.cpp,
 //       the returns should be preceded by emitResult().
-void AddToArchive::start(void)
+void AddToArchive::slotStartJob(void)
 {
-    kDebug(1601);
+    kDebug();
 
     Kerfuffle::CompressionOptions options;
 
@@ -100,7 +134,7 @@ void AddToArchive::start(void)
     Kerfuffle::Archive *archive;
     if (!m_filename.isEmpty()) {
         archive = Kerfuffle::factory(m_filename, m_mimeType);
-        kDebug(1601) << "Set filename to " + m_filename;
+        kDebug() << "Set filename to " + m_filename;
     } else {
         if (m_autoFilenameSuffix.isEmpty()) {
             KMessageBox::error(NULL, i18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the --autofilename argument."));
@@ -108,7 +142,7 @@ void AddToArchive::start(void)
         }
 
         if (m_firstPath.isEmpty()) {
-            kDebug(1601) << "Weird, this should not happen. no firstpath defined. aborting";
+            kDebug() << "Weird, this should not happen. no firstpath defined. aborting";
             return;
         }
 
@@ -131,7 +165,7 @@ void AddToArchive::start(void)
             finalName = base + '_' + QString::number(appendNumber) + '.' + m_autoFilenameSuffix;
         }
 
-        kDebug(1601) << "Autoset filename to " + finalName;
+        kDebug() << "Autoset filename to " + finalName;
         archive = Kerfuffle::factory(finalName, m_mimeType);
     }
 
@@ -143,18 +177,18 @@ void AddToArchive::start(void)
 
     if (m_changeToFirstPath) {
         if (m_firstPath.isEmpty()) {
-            kDebug(1601) << "Weird, this should not happen. no firstpath defined. aborting";
+            kDebug() << "Weird, this should not happen. no firstpath defined. aborting";
             return;
         }
 
-        QDir stripDir = QDir(m_firstPath);
+        const QDir stripDir(m_firstPath);
 
         for (int i = 0; i < m_inputs.size(); ++i) {
             m_inputs[i] = stripDir.absoluteFilePath(m_inputs.at(i));
         }
 
         options["GlobalWorkDir"] = stripDir.path();
-        kDebug(1601) << "Setting GlobalWorkDir to " << stripDir.path();
+        kDebug() << "Setting GlobalWorkDir to " << stripDir.path();
     }
 
     Kerfuffle::AddJob *job =
@@ -170,7 +204,7 @@ void AddToArchive::start(void)
 
 void AddToArchive::slotFinished(KJob *job)
 {
-    kDebug(1601);
+    kDebug();
 
     if (job->error()) {
         KMessageBox::error(NULL, job->errorText());
