@@ -146,7 +146,7 @@ void Part::registerJob(KJob* job)
             this, SIGNAL(ready()));
 }
 
-void Part::extractSelectedFilesTo(QString localPath)
+void Part::extractSelectedFilesTo(const QString& localPath)
 {
     kDebug() << "Extract to " << localPath;
     if (!m_model) return;
@@ -484,7 +484,10 @@ void Part::slotPreview(const QModelIndex & index)
     const ArchiveEntry& entry =  m_model->entryForIndex(index);
 
     if (!entry.isEmpty()) {
-        ExtractJob *job = m_model->extractFile(entry[ InternalID ], m_previewDir->name());
+        Kerfuffle::ExtractionOptions options;
+        options["PreservePaths"] = true;
+
+        ExtractJob *job = m_model->extractFile(entry[ InternalID ], m_previewDir->name(), options);
         registerJob(job);
         connect(job, SIGNAL(result(KJob*)),
                 this, SLOT(slotPreviewExtracted(KJob*)));
@@ -495,10 +498,10 @@ void Part::slotPreview(const QModelIndex & index)
 void Part::slotPreviewExtracted(KJob *job)
 {
     if (!job->error()) {
-        //ArkViewer viewer( widget() );
-        const ArchiveEntry& entry =  m_model->entryForIndex(m_view->selectionModel()->currentIndex());
-        const QString name = entry[ FileName ].toString().split('/', QString::SkipEmptyParts).last();
-        const QString fullName = m_previewDir->name() + '/' + name;
+        const ArchiveEntry& entry =
+            m_model->entryForIndex(m_view->selectionModel()->currentIndex());
+        const QString fullName =
+            m_previewDir->name() + '/' + entry[ FileName ].toString();
         ArkViewer::view(fullName, widget());
     } else {
         KMessageBox::error(widget(), job->errorString());
