@@ -33,7 +33,7 @@ using namespace Kerfuffle;
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
         : CliInterface(parent, args)
-        , m_state(0)
+        , m_state(ReadStateHeader)
 {
 }
 
@@ -75,46 +75,56 @@ ParameterList CliPlugin::parameterList() const
 
 bool CliPlugin::readListLine(const QString &line)
 {
+    static const QLatin1String archiveInfoDelimiter("----");
+    static const QLatin1String entryInfoDelimiter("----------");
+
     switch (m_state) {
-    case 0: // header
+    case ReadStateHeader:
         if (line.startsWith(QLatin1String("Listing archive:"))) {
-            kDebug() << "Archive name: " << line.right(line.size() - 16).trimmed();
-        } else if (line.startsWith(QLatin1String("----------"))) {
-            m_state = 1;
+            kDebug() << "Archive name: "
+                     << line.right(line.size() - 16).trimmed();
+        } else if (line == archiveInfoDelimiter) {
+            m_state = ReadStateArchiveInformation;
         } else if (line.contains("Error:")) {
             kDebug() << line.mid(6);
-            //m_errorMessages << line.mid(6);
-        }
-        break;
-    case 1: // beginning of a file detail
-        if (line.startsWith(QLatin1String("Path ="))) {
-            m_currentArchiveEntry.clear();
-            QString entryFilename = QDir::fromNativeSeparators(line.mid(6).trimmed());
-            m_currentArchiveEntry[FileName] = entryFilename;
-            m_currentArchiveEntry[InternalID] = entryFilename;
-            m_state = 2;
         }
         break;
 
-    case 2: // file details
-        if (line.startsWith(QLatin1String("Size = "))) {
+    case ReadStateArchiveInformation:
+        if (line == entryInfoDelimiter) {
+            m_state = ReadStateEntryInformation;
+        }
+        break;
+
+    case ReadStateEntryInformation:
+        if (line.startsWith(QLatin1String("Path ="))) {
+            const QString entryFilename =
+                QDir::fromNativeSeparators(line.mid(6).trimmed());
+            m_currentArchiveEntry.clear();
+            m_currentArchiveEntry[FileName] = entryFilename;
+            m_currentArchiveEntry[InternalID] = entryFilename;
+        } else if (line.startsWith(QLatin1String("Size = "))) {
             m_currentArchiveEntry[ Size ] = line.mid(7).trimmed();
         } else if (line.startsWith(QLatin1String("Packed Size = "))) {
             m_currentArchiveEntry[ CompressedSize ] = line.mid(14).trimmed();
         } else if (line.startsWith(QLatin1String("Modified = "))) {
-            QDateTime ts = QDateTime::fromString(line.mid(11).trimmed(), "yyyy-MM-dd hh:mm:ss");
-            m_currentArchiveEntry[ Timestamp ] = ts;
+            m_currentArchiveEntry[ Timestamp ] =
+                QDateTime::fromString(line.mid(11).trimmed(),
+                                      "yyyy-MM-dd hh:mm:ss");
         } else if (line.startsWith(QLatin1String("Attributes = "))) {
-            QString attributes = line.mid(13).trimmed();
+            const QString attributes = line.mid(13).trimmed();
 
-            bool isDirectory = attributes.startsWith('D');
+            const bool isDirectory = attributes.startsWith('D');
             m_currentArchiveEntry[ IsDirectory ] = isDirectory;
             if (isDirectory) {
-                QString directoryName = m_currentArchiveEntry[FileName].toString();
+                const QString directoryName =
+                    m_currentArchiveEntry[FileName].toString();
                 if (!directoryName.endsWith('/')) {
-                    m_currentArchiveEntry[FileName] = m_currentArchiveEntry[InternalID] = directoryName + '/';
-                    bool isPasswordProtected = (line.at(12) == '+');
-                    m_currentArchiveEntry[ IsPasswordProtected ] = isPasswordProtected;
+                    const bool isPasswordProtected = (line.at(12) == '+');
+                    m_currentArchiveEntry[FileName] =
+                        m_currentArchiveEntry[InternalID] = directoryName + '/';
+                    m_currentArchiveEntry[ IsPasswordProtected ] =
+                        isPasswordProtected;
                 }
             }
 
@@ -122,22 +132,16 @@ bool CliPlugin::readListLine(const QString &line)
         } else if (line.startsWith(QLatin1String("CRC = "))) {
             m_currentArchiveEntry[ CRC ] = line.mid(6).trimmed();
         } else if (line.startsWith(QLatin1String("Method = "))) {
-            QString method = line.mid(9).trimmed();
-            m_currentArchiveEntry[ Method ] = method;
-        } else if (line.startsWith(QLatin1String("Encrypted = ")) && line.size() >= 13) {
-            bool isPasswordProtected = (line.at(12) == '+');
-            m_currentArchiveEntry[ IsPasswordProtected ] = isPasswordProtected;
+            m_currentArchiveEntry[ Method ] = line.mid(9).trimmed();
+        } else if (line.startsWith(QLatin1String("Encrypted = ")) &&
+                   line.size() >= 13) {
+            m_currentArchiveEntry[ IsPasswordProtected ] = (line.at(12) == '+');
         } else if (line.startsWith(QLatin1String("Block = "))) {
             if (m_currentArchiveEntry.contains(FileName)) {
                 entry(m_currentArchiveEntry);
             }
-
-            m_state = 1;
         }
         break;
-
-    default:
-        break;
     }
 
     return true;
