@@ -31,7 +31,7 @@ class CliPlugin : public Kerfuffle::CliInterface
     Q_OBJECT
 
 public:
-    explicit CliPlugin(const QString & filename, QObject *parent = 0);
+    explicit CliPlugin(QObject *parent, const QVariantList & args);
     virtual ~CliPlugin();
 
 protected:
@@ -39,8 +39,14 @@ protected:
     virtual bool readListLine(const QString &line);
 
 private:
+    enum ReadState {
+	ReadStateHeader = 0,
+	ReadStateArchiveInformation,
+	ReadStateEntryInformation
+    };
+
     Kerfuffle::ArchiveEntry m_currentArchiveEntry;
-    int m_state;
+    ReadState m_state;
 };
 
 #endif // CLIPLUGIN_H
