@@ -30,13 +30,13 @@ class CliPlugin : public Kerfuffle::CliInterface
     Q_OBJECT
 
 public:
-    explicit CliPlugin(const QString & filename, QObject *parent = 0);
+    explicit CliPlugin(QObject *parent, const QVariantList & args);
 
     virtual ~CliPlugin();
 
     virtual Kerfuffle::ParameterList parameterList() const;
 
-    virtual bool readListLine(QString line);
+    virtual bool readListLine(const QString &line);
 
 protected:
     QString m_entryFilename;
